/* PRT - Text file print utility                                              */
/* Copyright (c) 1990 by David Sanders                                        */

// Include files for library functions
#include <stdio.h>
#include <string.h>
#include <dos.h>

// Global definitions
#define TRUE  1
#define FALSE 0
#define VERSION "Version 1.21     Nov 11, 1990"

// Function prototypes
int process_file(void);
void print_header(int page);
void print_line(int line_num, char *line);
void usage(void);
void setup_printer(void);        /* These two functions are printer   */
void un_setup_printer(void);     /* specific and are defined in prt.h */

// Global variables
int land_mode, number_mode, nlq_mode, book_mode, header_mode, max;
char filename[35];

// Include file for printer specific definitions and functions
#include "prt.h"         /* Note that this include directive must appear */
			 /* after the Global variables are declared      */

main(int argc, char *argv[])
{   /* Main program starts here */
    int i, j, code;
    max=LINES_PER_PAGE_PORTRAIT;
    land_mode = book_mode = nlq_mode = header_mode = number_mode = FALSE;
    code = 0;

    // Print program signature
    fprintf(stdout,"PRT - Text file print utility for %s\n",PRINTER_TYPE);
    fprintf(stdout,"%s\n",VERSION);
    fprintf(stdout,"Copyright (c) 1990 by David Sanders\n");

    // Get file name(s) and option(s) from command line
    if (!(argc > 1)) {
	usage();   // if nothing on command line, print usage and options
	return 0;
    }
    else {
	i = argc - 1;
	while (argv[i][0] == '-') {
	    if (strcmp(argv[i],"-l") == 0) {
		land_mode = TRUE;
		max=LINES_PER_PAGE_LANDSCAPE;
	    }
	    else if (strcmp(argv[i],"-h") == 0) header_mode = TRUE;
	    else if (strcmp(argv[i],"-n") == 0) number_mode = TRUE;
	    else if (strcmp(argv[i],"-q") == 0) nlq_mode = TRUE;
#ifdef BOOK
	    else if (strcmp(argv[i],"-2") == 0) {
		land_mode = TRUE;
		book_mode = TRUE;
		max=LINES_PER_PAGE_BOOK;
	    }
#endif
	    i--;
	}
	for (j=1;j<=i;j++) { 
		strcpy(filename,argv[j]);
		code = process_file();
	}
    }
    return code;
} /* End of main */

int process_file(void) {

    //Local variables
    FILE *textfile;
    char line[130];
    int i, page, linenum;
    linenum = 0;

    if (header_mode == TRUE) max -= 2;

    // Open input file if it exits
    if ((textfile = fopen(filename,"r")) == NULL) {
        fprintf(stderr, "Cannot open input file: %s",filename);
	return 1;
    }

    // Printer setup
    setup_printer();

    // Send file to printer one line at a time.
    fprintf(stdout,"Printing file: %s . . .",filename);
    i=0;
    page=1;
    if (header_mode == TRUE) print_header(page);
    while (fgets(line, 125, textfile) != NULL) {
	i++; linenum++;
	print_line(linenum,line);
	if (i >= max) {
		page++;
#ifdef BOOK
		if (book_mode) {
			if (!(page % 2)) {
				if (!(number_mode)) printer(L_MARGIN_105);
				else printer(L_MARGIN_101);
                                printer(MOVE_TO_TOP);
			}
			else {
				printer(L_MARGIN_5);
				printer(FORM_FEED);
			}
		}
#endif
#ifdef EPSON
                printer(FORM_FEED);
#endif
		if (header_mode) print_header(page);
		i=0;
	}
    }
    fclose(textfile);
    fprintf(stdout," Done.\n");

    // Return printer to defaults and prints a form feed
    un_setup_printer();
    if (!(book_mode) && !(land_mode)) printer(FORM_FEED);

    return 0; /* End of process_file*/
}

void print_header(int page)
{
	struct date d;
	struct time t;
	fprintf(stdprn,"%s\t\t\t",filename);
	if (page == 1) { 
	    getdate(&d);
	    gettime(&t);
	    fprintf(stdprn,"%d/%d/%d",d.da_mon,d.da_day,d.da_year);
	    fprintf(stdprn,"  %2d:%02d",t.ti_hour, t.ti_min);
	    fprintf(stdprn,"\t\t\tpage 1\n\n");
	}
	else fprintf(stdprn,"\t\t\t\t\tpage %d\n\n",page);
	return;
}

void print_line(int linenum, char *line)
{
	if (number_mode) fprintf(stdprn,"%5d:  %s",linenum,line);
	else fprintf(stdprn,"%s",line);
	return;
}

void usage(void) {
        fprintf(stderr,"USAGE: prt <filename(s)> <option(s)>\n");
// Note that LAND and NLQ must be defined in prt.h if it is to be used
#ifdef LAND
	fprintf(stderr,"       options:   -l   landscape mode printing\n");
#endif
#ifdef BOOK
    fprintf(stderr,"                  -2   2 pages on one side, landscape\n");
#endif
	fprintf(stderr,"                  -h   header on each page\n");
	fprintf(stderr,"                  -n   add line numbers");
#ifdef NLQ
	fprintf(stderr,"\n                  -q   near letter quality");
#endif
	return;
}
