// PRT.H
// Copyright (c) 1990 by David Sanders
// PRT - Text file print utility
#ifdef PAINTJET
/* HP Paintjet definitions and printer specific functions for prt.c           */

// LAND means printer can print in landscape mode
#define LAND
// BOOK means printer can print in "book" mode
#define BOOK

// Constants
#define LINES_PER_PAGE_PORTRAIT 60
#define LINES_PER_PAGE_LANDSCAPE 45
#define LINES_PER_PAGE_BOOK 66
#define PRINTER_TYPE "HP Paintjet XL"

// Reset printer to defaults
#define RESET "\x1B\x45"
// Set printer to print in landscape mode
#define LANDSCAPE "\x1B\x26\x6C\x31\x4F"
// Set printer to print in portrait mode (default)
#define PORTRAIT "\x1B\x26\x6C\x30\x4F"
// Set left margin to 5 columns
#define L_MARGIN_5 "\x1B\x26\x61\x35\x4C"
// Set left margin to 101 columns
#define L_MARGIN_101 "\x1B\x26\x61\x31\x30\x31\x4C"
// Set left margin to 105 columns
#define L_MARGIN_105 "\x1B\x26\x61\x31\x30\x35\x4C"
// Set left margin to 0 columns (default)
#define L_MARGIN_0 "\x1B\x26\x61\x30\x4C"
// Set auto line termination mode (so that LF becomes LF+CR)
#define AUTO_LINE_MODE "\x1B\x26\x6B\x33\x47"
// Set auto line termination back to default
#define UN_AUTO_LINE_MODE "\x1B\x26\x6B\x30\x47"
// Set printer to use 12 cpi pitch
#define CPI_12 "\x1B\x26\x6B\x34\x53"
// Set printer to use 10 cpi pitch  (default)
#define CPI_10 "\x1B\x26\x6B\x30\x53"
// Set printer to use 18 cpi pitch
#define CPI_18 "\x1B\x26\x6B\x32\x53"
// Set printer to use 6 lines/inch
#define LINE_SPACE_6 "\x1B\x26\x6C\x36\x44"
// Set printer to use 9 lines/inch
#define LINE_SPACE_9 "\x1B\x26\x6C\x39\x44"
// Move to top of page (relative up 66 lines)
#define MOVE_TO_TOP "\x1B\x26\x61\x2D\x36\x36\x52"
// Form feed
#define FORM_FEED "\x0C"

// Macro to send printer control strings
#define printer(c) fprintf(stdprn,"%s",c)

// define external variable
extern int land_mode;
extern int book_mode;

// Function to set up printer for this program
void setup_printer(void)
{
	if (land_mode) printer(LANDSCAPE);
	else printer(PORTRAIT);
        printer(AUTO_LINE_MODE);
	if (!(book_mode)) printer(CPI_12);
	else {
		printer(CPI_18);
		printer(LINE_SPACE_9);
	}
	printer(L_MARGIN_5);
	return;
}

// Function to return printer to defaults
void un_setup_printer(void)
{
	printer(UN_AUTO_LINE_MODE);
	printer(L_MARGIN_0);
	printer(LINE_SPACE_6);
	printer(CPI_10);
	printer(PORTRAIT);
	return;
}

#endif

#ifdef EPSON
/* Definition file for EPSON printers (FX-850)                              */

// NLQ means printer has a "near letter quality" mode
#define NLQ

// Constants
#define LINES_PER_PAGE_PORTRAIT 64
#define LINES_PER_PAGE_LANDSCAPE 64
#define LINES_PER_PAGE_BOOK 64
#define PRINTER_TYPE "Epson FX-850"

// Form feed
#define FORM_FEED "\x0C"

#define printer(c) fprintf(stdprn,"%s",c)

void setup_printer(void)
{
	// Set left margin to 5
	fprintf(stdprn,"%c%c%c",27,108,5);
	if (nlq_mode) {
		// Set font 0 - Roman, 1 - Sans Serif
		fprintf(stdprn,"%c%c%c",27,107,0);
		// Set NLQ mode
		fprintf(stdprn,"%c%c%c",27,120,1);
	}
	// Set draft mode
	else fprintf(stdprn,"%c%c%c",27,120,0);
	// Set 12 cpi operation
	fprintf(stdprn,"%c%c",27,77);
	return;
}

void un_setup_printer(void)
{
	// Set 10 cpi operation
	fprintf(stdprn,"%c%c",27,80);
	// Set draft mode
	fprintf(stdprn,"%c%c%c",27,108,0);
	// Set left margin to 0
	fprintf(stdprn,"%c%c%c",27,120,0);
	return;
}

#endif
